$icomoon-font-path: "fonts" !default;

$icon-settings: "\e900";
$icon-menu: "\e901";
$icon-reset: "\e61e";
$icon-search: "\e61d";
$icon-user: "\e61c";
$icon-jet: "\e61b";
$icon-refresh: "\e61a";
$icon-grid: "\e619";
$icon-star: "\e618";
$icon-pin: "\e617";
$icon-new: "\e616";
$icon-edit: "\e615";
$icon-clock: "\e611";
$icon-calendar: "\e612";
$icon-book: "\e60d";
$icon-open-external: "\e60e";
$icon-data: "\e60f";
$icon-question: "\e613";
$icon-tick: "\e614";
$icon-cross: "\e610";
$icon-key: "\e60c";
$icon-arrow-right: "\e60b";
$icon-arrow-left: "\e60a";
$icon-arrow-down: "\e608";
$icon-arrow-up: "\e609";
$icon-checkbox-outline: "\e607";
$icon-remove: "\e600";
$icon-add2: "\e601";
$icon-exit: "\e602";
$icon-add: "\e603";
$icon-add3: "\e604";
$icon-expand: "\e605";
$icon-checkbox: "\e606";
$icon-edit-icon: "\e902";
$icon-retainer-tick: "\e903";
$icon-retainer-plus: "\e904";
$icon-retainer-trash: "\e905";