@charset "UTF-8";
/*
 * Customizable variables
 * Update these variable to create theme
 */
/*
 * Base Colours
 */
/*
 * General
 */
/*
* Sidebar
*/
/*
* Top
*/
/*
* Content
*/
/*
* Buttons
*/
/*
* Inputs
*/
/*
* Messages
*/
/*
* Login
*/
/*
* jQuery UI
*/
/*
* Charts
*/
/*
 * Default variable values
 * Create separate themes/theme/_variables.scss to override these variables
 */
/*
 * General
 */
/*
 * Sidebar
 */
/*
 * Top
 */
/*
 * Content
 */
/*
 * Buttons
 */
/*
 * Inputs
 */
/*
 * Messages
 */
/*
 * Login
 */
/*
 * jQuery UI
 */
/*
 * Charts
 */
.hidden {
  display: none;
}

.clear-list {
  margin: 0;
  padding: 0;
  list-style: none;
}

.fl {
  float: left;
}

.fr {
  float: right;
}

.cf:before, .cf:after {
  content: "";
  display: table;
}

.cf:after {
  clear: both;
}

.p10 {
  padding: 10px;
}

.p20 {
  padding: 20px;
}

.p30 {
  padding: 30px;
}

.p40 {
  padding: 40px;
}

.p50 {
  padding: 50px;
}

.p60 {
  padding: 60px;
}

.p70 {
  padding: 70px;
}

.p80 {
  padding: 80px;
}

.pt10 {
  padding-top: 10px;
}

.pt20 {
  padding-top: 20px;
}

.pt30 {
  padding-top: 30px;
}

.pt40 {
  padding-top: 40px;
}

.pt50 {
  padding-top: 50px;
}

.pt60 {
  padding-top: 60px;
}

.pt70 {
  padding-top: 70px;
}

.pt80 {
  padding-top: 80px;
}

.pr10 {
  padding-right: 10px;
}

.pr20 {
  padding-right: 20px;
}

.pr30 {
  padding-right: 30px;
}

.pr40 {
  padding-right: 40px;
}

.pr50 {
  padding-right: 50px;
}

.pr60 {
  padding-right: 60px;
}

.pr70 {
  padding-right: 70px;
}

.pr80 {
  padding-right: 80px;
}

.pb10 {
  padding-bottom: 10px;
}

.pb20 {
  padding-bottom: 20px;
}

.pb30 {
  padding-bottom: 30px;
}

.pb40 {
  padding-bottom: 40px;
}

.pb50 {
  padding-bottom: 50px;
}

.pb60 {
  padding-bottom: 60px;
}

.pb70 {
  padding-bottom: 70px;
}

.pb80 {
  padding-bottom: 80px;
}

.pl10 {
  padding-left: 10px;
}

.pl20 {
  padding-left: 20px;
}

.pl30 {
  padding-left: 30px;
}

.pl40 {
  padding-left: 40px;
}

.pl50 {
  padding-left: 50px;
}

.pl60 {
  padding-left: 60px;
}

.pl70 {
  padding-left: 70px;
}

.pl80 {
  padding-left: 80px;
}

.m10 {
  margin: 10px;
}

.m20 {
  margin: 20px;
}

.m30 {
  margin: 30px;
}

.m40 {
  margin: 40px;
}

.m50 {
  margin: 50px;
}

.m60 {
  margin: 60px;
}

.m70 {
  margin: 70px;
}

.m80 {
  margin: 80px;
}

.mt10 {
  margin-top: 10px;
}

.mt20 {
  margin-top: 20px;
}

.mt30 {
  margin-top: 30px;
}

.mt40 {
  margin-top: 40px;
}

.mt50 {
  margin-top: 50px;
}

.mt60 {
  margin-top: 60px;
}

.mt70 {
  margin-top: 70px;
}

.mt80 {
  margin-top: 80px;
}

.mr10 {
  margin-right: 10px;
}

.mr20 {
  margin-right: 20px;
}

.mr30 {
  margin-right: 30px;
}

.mr40 {
  margin-right: 40px;
}

.mr50 {
  margin-right: 50px;
}

.mr60 {
  margin-right: 60px;
}

.mr70 {
  margin-right: 70px;
}

.mr80 {
  margin-right: 80px;
}

.mb10 {
  margin-bottom: 10px;
}

.mb20 {
  margin-bottom: 20px;
}

.mb30 {
  margin-bottom: 30px;
}

.mb40 {
  margin-bottom: 40px;
}

.mb50 {
  margin-bottom: 50px;
}

.mb60 {
  margin-bottom: 60px;
}

.mb70 {
  margin-bottom: 70px;
}

.mb80 {
  margin-bottom: 80px;
}

.ml10 {
  margin-left: 10px;
}

.ml20 {
  margin-left: 20px;
}

.ml30 {
  margin-left: 30px;
}

.ml40 {
  margin-left: 40px;
}

.ml50 {
  margin-left: 50px;
}

.ml60 {
  margin-left: 60px;
}

.ml70 {
  margin-left: 70px;
}

.ml80 {
  margin-left: 80px;
}

.pos_rel {
  position: relative;
}

.pos_abs {
  position: absolute;
}

.fill_width {
  width: 100% !important;
}

@-webkit-keyframes spin {
  100% {
    -webkit-transform: rotate(360deg);
            transform: rotate(360deg);
  }
}

@keyframes spin {
  100% {
    -webkit-transform: rotate(360deg);
            transform: rotate(360deg);
  }
}

.ui-widget-content {
  color: #161616;
  border-color: #cbcbcb;
  padding: 0;
}

.ui-widget.ui-widget-content, .ui-timepicker-table.ui-widget-content {
  background: #fff;
  -webkit-box-shadow: 0 0 10px 0 rgba(0, 0, 0, 0.5);
          box-shadow: 0 0 10px 0 rgba(0, 0, 0, 0.5);
}

.ui-widget {
  font-family: inherit;
  font-size: inherit;
}

.ui-widget-header {
  background-color: #fff;
  background-image: none;
  border: 0;
  color: #161616;
  font-weight: 400;
  font-size: 1.5rem;
  line-height: 1.875rem;
  border-bottom: 1px solid #cbcbcb;
  border-radius: 0;
}

.ui-widget-header a {
  color: #161616;
}

.ui-state-default, .ui-widget-content .ui-state-default, .ui-widget-header .ui-state-default {
  border: 1px solid #cbcbcb;
  background: #fff;
  font-weight: bold;
  color: #161616;
  border-radius: 4px;
}

.ui-widget-header .ui-state-default {
  background: none;
  color: #161616;
  border: 0;
}

.ui-state-hover, .ui-widget-content .ui-state-hover, .ui-widget-header .ui-state-hover, .ui-state-focus, .ui-widget-content .ui-state-focus, .ui-widget-header .ui-state-focus {
  border: 1px solid #42cf77;
  background: #42cf77;
  font-weight: bold;
  color: #fff;
}

.ui-state-active, .ui-widget-content .ui-state-active, .ui-widget-header .ui-state-active {
  border: 1px solid #42cf77;
  background: #42cf77;
  font-weight: bold;
  color: #fff;
}

.ui-state-highlight, .ui-widget-content .ui-state-highlight, .ui-widget-header .ui-state-highlight {
  border: 1px solid #42cf77;
  background: #fff;
  color: #42cf77;
}

@media only screen and (max-width: 480px) {
  .ui-dialog {
    left: 10px !important;
    right: 10px !important;
    width: auto !important;
  }
}

.ui-dialog-buttonpane {
  background: #fff;
  margin: .5em -0.2em -0.2em -0.2em;
}

.ui-dialog-buttonpane .ui-button {
  border: 1px solid #cbcbcb !important;
  border-radius: 0;
  outline: 0;
  padding: 10px 30px;
  font-weight: 700;
  font-size: 12px;
  letter-spacing: .125rem;
  text-align: center;
  text-transform: uppercase;
  background-color: transparent;
  border: 1px solid transparent;
  -webkit-transition: background-color .3s,border .3s,color .3s;
  transition: background-color .3s,border .3s,color .3s;
  letter-spacing: .0625rem;
}

.ui-dialog-buttonpane .ui-button:hover {
  background-color: #161616;
  color: #fff;
}

.ui-dialog-buttonpane .ui-button:hover {
  background-color: #161616;
  border-color: #161616;
  color: #fff;
}

.ui-icon {
  font-family: 'jet-icons';
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  display: inline-block;
  font-size: 16px;
  font-weight: bold;
  background: none !important;
  text-indent: 0;
  overflow: visible;
}

.ui-widget-overlay {
  background: #161616;
  opacity: 0.5;
  filter: Alpha(Opacity=50);
}

.ui-tooltip {
  background: #161616 !important;
  padding: 5px 10px;
  color: #fff;
  border: 0;
  -webkit-box-shadow: none !important;
          box-shadow: none !important;
  opacity: 0.8;
  font-size: 13px;
  pointer-events: none;
}

.ui-datepicker table, .ui-timepicker table {
  margin: 0 0 .4em;
  background: transparent;
  border-radius: 0;
  -webkit-box-shadow: none;
          box-shadow: none;
}

.ui-datepicker th, .ui-timepicker th {
  background: inherit;
  color: inherit;
  text-transform: inherit;
}

.ui-datepicker tbody tr, .ui-timepicker tbody tr {
  border-bottom: inherit;
}

.ui-datepicker tbody tr:nth-child(odd), .ui-timepicker tbody tr:nth-child(odd) {
  background-color: inherit;
}

.ui-datepicker table {
  margin: 0 0 .4em;
}

.ui-timepicker-table table {
  margin: .15em 0 0;
}

.ui-button-text-only .ui-button-text {
  padding: 0;
}

.ui-dialog-titlebar-close {
  -webkit-box-shadow: none;
          box-shadow: none;
}

.ui-dialog-titlebar-close:hover {
  background-color: transparent;
  border: 1px solid transparent;
  color: #d0021b;
}

.ui-dialog-content {
  padding: 20px;
}

#bookmarks-add-form p {
  margin-top: 10px;
  margin-bottom: 10px;
}

#bookmarks-add-form input[type="text"] {
  margin-bottom: 15px;
}

.ui-dialog-buttonset .ui-button:first-of-type {
  background-color: #42cf77;
  color: #fff;
}

.ui-dialog-buttonset .ui-button:first-of-type:hover {
  background-color: #3caf4a;
}

.ui-widget-header {
  background-color: #fff;
}

.ui-dialog-buttonpane {
  background-color: #fff;
}

.ui-datepicker table {
  margin-top: 10px;
  margin-bottom: 10px;
}

.ui-datepicker .ui-datepicker-buttonpane button,
.ui-timepicker .ui-timepicker-buttonpane button {
  border: 1px solid #cbcbcb !important;
  border-radius: 0;
  outline: 0;
  padding: 10px 30px;
  font-weight: 700;
  font-size: 12px;
  letter-spacing: .125rem;
  text-align: center;
  text-transform: uppercase;
  background-color: transparent;
  border: 1px solid transparent;
  -webkit-transition: background-color .3s,border .3s,color .3s;
  transition: background-color .3s,border .3s,color .3s;
  letter-spacing: .0625rem;
  text-transform: none;
  opacity: 1;
}

.ui-datepicker .ui-datepicker-buttonpane button:hover,
.ui-timepicker .ui-timepicker-buttonpane button:hover {
  background-color: #161616;
  color: #fff;
}

.ui-datepicker button.ui-datepicker-close,
.ui-timepicker button.ui-timepicker-close {
  background-color: #42cf77;
  color: #fff;
}

.ui-datepicker button.ui-datepicker-close:hover,
.ui-timepicker button.ui-timepicker-close:hover {
  background-color: #3caf4a;
}

.ui-datepicker-calendar .ui-state-default,
.ui-timepicker-table .ui-state-default {
  padding: 2px;
  text-align: center;
  font-weight: 400;
  border: none;
}

.ui-datepicker-calendar .ui-state-hover {
  border: none;
}

.ui-datepicker-header {
  background-color: #000;
  color: #fff;
}

.ui-datepicker .ui-datepicker-prev,
.ui-datepicker .ui-datepicker-next {
  color: #fff;
  cursor: pointer;
}

.ui-icon-circle-triangle-e:before {
  content: "";
}

.ui-icon-circle-triangle-w:before {
  content: "";
}

.ui-datepicker-title {
  margin: 0 2.3em;
  line-height: 1.8em;
  background-color: #161616;
  color: #fff;
  font-size: 16px;
  padding: 5px 0;
}

.ui-timepicker-title {
  background-color: #161616;
  color: #fff;
  font-size: 16px;
  text-align: center;
  padding: 5px 0;
}

.ui-timepicker-table table {
  margin: 10px 0;
}

.ui-datepicker td,
.ui-timepicker-table td {
  padding: 3px;
}
/*# sourceMappingURL=jquery-ui.theme.css.map */