.select2-container,
.ui-button,
.ui-spinner,
.ui-spinner-input {
  vertical-align: middle;
}
.ps-container.ps-in-scrolling,
.ps-container:hover.ps-in-scrolling {
  pointer-events: none;
}
.select2-container {
  box-sizing: border-box;
  display: inline-block;
  margin: 0;
  position: relative;
}
.select2-container .select2-selection--single {
  box-sizing: border-box;
  cursor: pointer;
  display: block;
  height: 28px;
  height: 2rem;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  -webkit-user-select: none;
}
.select2-container .select2-selection--single .select2-selection__rendered {
  display: block;
  padding-left: 0.57143rem;
  padding-right: 1.42857rem;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.select2-container[dir='rtl']
  .select2-selection--single
  .select2-selection__rendered {
  padding-right: 0.57143rem;
  padding-left: 1.42857rem;
}
.select2-container .select2-selection--multiple {
  box-sizing: border-box;
  cursor: pointer;
  display: block;
  min-height: 32px;
  min-height: 2.28571rem;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  -webkit-user-select: none;
}
.select2-container .select2-selection--multiple .select2-selection__rendered {
  display: inline-block;
  overflow: hidden;
  padding-left: 0.57143rem;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.select2-container .select2-search--inline {
  float: left;
}
.select2-container .select2-search--inline .select2-search__field {
  box-sizing: border-box;
  border: none;
  font-size: 100%;
  margin-top: 0.35714rem;
}
.select2-container
  .select2-search--inline
  .select2-search__field::-webkit-search-cancel-button {
  -webkit-appearance: none;
}
.select2-dropdown {
  background-color: #fff;
  border: 1px solid #aaa;
  border: 0.07143rem solid #aaa;
  border-radius: 0.28571rem;
  box-sizing: border-box;
  display: block;
  position: absolute;
  left: -100000px;
  left: -7142.85714rem;
  width: 100%;
  z-index: 1051;
}
.select2-results {
  display: block;
}
.select2-results__options {
  list-style: none;
  margin: 0;
  padding: 0;
}
.select2-results__option {
  padding: 0.42857rem;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  -webkit-user-select: none;
}
.select2-results__option[aria-selected] {
  cursor: pointer;
}
.select2-container--open .select2-dropdown {
  left: 0;
}
.select2-container--open .select2-dropdown--above {
  border-bottom: none;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}
.select2-container--open .select2-dropdown--below {
  border-top: none;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.select2-search--dropdown {
  display: block;
  padding: 0.28571rem;
}
.select2-search--dropdown .select2-search__field {
  padding: 0.28571rem;
  width: 100%;
  box-sizing: border-box;
}
.select2-search--dropdown .select2-search__field::-webkit-search-cancel-button {
  -webkit-appearance: none;
}
.select2-search--dropdown.select2-search--hide {
  display: none;
}
.select2-close-mask {
  border: 0;
  margin: 0;
  padding: 0;
  display: block;
  position: fixed;
  left: 0;
  top: 0;
  min-height: 100%;
  min-width: 100%;
  height: auto;
  width: auto;
  opacity: 0;
  z-index: 99;
  background-color: #fff;
  filter: alpha(opacity=0);
}
.select2-hidden-accessible {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  height: 0.07143rem;
  margin: -0.07143rem;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px;
  width: 0.07143rem;
}
.select2-container--default .select2-selection--single {
  background-color: #fff;
  border: 1px solid #aaa;
  border: 0.07143rem solid #aaa;
  border-radius: 0.28571rem;
}
.select2-container--default
  .select2-selection--single
  .select2-selection__rendered {
  color: #444;
  line-height: 28px;
  line-height: 2rem;
}
.select2-container--default
  .select2-selection--single
  .select2-selection__clear {
  cursor: pointer;
  float: right;
  font-weight: 700;
}
.select2-container--default
  .select2-selection--single
  .select2-selection__placeholder {
  color: #999;
}
.select2-container--default
  .select2-selection--single
  .select2-selection__arrow {
  height: 26px;
  height: 1.85714rem;
  position: absolute;
  top: 1px;
  top: 0.07143rem;
  right: 1px;
  right: 0.07143rem;
  width: 20px;
  width: 1.42857rem;
}
.select2-container--default
  .select2-selection--single
  .select2-selection__arrow
  b {
  border-color: #888 transparent transparent;
  border-style: solid;
  border-width: 0.35714rem 0.28571rem 0;
  height: 0;
  left: 50%;
  margin-left: -0.28571rem;
  margin-top: -0.14286rem;
  position: absolute;
  top: 50%;
  width: 0;
}
.select2-container--default[dir='rtl']
  .select2-selection--single
  .select2-selection__clear {
  float: left;
}
.select2-container--default[dir='rtl']
  .select2-selection--single
  .select2-selection__arrow {
  left: 1px;
  left: 0.07143rem;
  right: auto;
}
.select2-container--default.select2-container--disabled
  .select2-selection--single {
  background-color: #eee;
  cursor: default;
}
.select2-container--default.select2-container--disabled
  .select2-selection--single
  .select2-selection__clear {
  display: none;
}
.select2-container--default.select2-container--open
  .select2-selection--single
  .select2-selection__arrow
  b {
  border-color: transparent transparent #888;
  border-width: 0 0.28571rem 0.35714rem;
}
.select2-container--default .select2-selection--multiple {
  background-color: #fff;
  border: 1px solid #aaa;
  border: 0.07143rem solid #aaa;
  border-radius: 0.28571rem;
  cursor: text;
}
.select2-container--default
  .select2-selection--multiple
  .select2-selection__rendered {
  box-sizing: border-box;
  list-style: none;
  margin: 0;
  padding: 0 0.35714rem;
  width: 100%;
}
.select2-container--default
  .select2-selection--multiple
  .select2-selection__placeholder {
  color: #999;
  margin-top: 0.35714rem;
  float: left;
}
.select2-container--default
  .select2-selection--multiple
  .select2-selection__clear {
  cursor: pointer;
  float: right;
  font-weight: 700;
  margin-top: 0.35714rem;
  margin-right: 0.71429rem;
}
.select2-container--default
  .select2-selection--multiple
  .select2-selection__choice {
  background-color: #e4e4e4;
  border: 1px solid #aaa;
  border: 0.07143rem solid #aaa;
  border-radius: 0.28571rem;
  cursor: default;
  float: left;
  margin-right: 0.35714rem;
  margin-top: 0.35714rem;
  padding: 0 0.35714rem;
}
.select2-container--default
  .select2-selection--multiple
  .select2-selection__choice__remove {
  color: #999;
  cursor: pointer;
  display: inline-block;
  font-weight: 700;
  margin-right: 0.14286rem;
}
.select2-container--default
  .select2-selection--multiple
  .select2-selection__choice__remove:hover {
  color: #333;
}
.select2-container--default[dir='rtl']
  .select2-selection--multiple
  .select2-selection__choice,
.select2-container--default[dir='rtl']
  .select2-selection--multiple
  .select2-selection__placeholder {
  float: right;
}
.select2-container--default[dir='rtl']
  .select2-selection--multiple
  .select2-selection__choice {
  margin-left: 0.35714rem;
  margin-right: auto;
}
.select2-container--default[dir='rtl']
  .select2-selection--multiple
  .select2-selection__choice__remove {
  margin-left: 0.14286rem;
  margin-right: auto;
}
.select2-container--default.select2-container--focus
  .select2-selection--multiple {
  border: 1px solid #000;
  border: 0.07143rem solid #000;
  outline: 0;
}
.select2-container--default.select2-container--disabled
  .select2-selection--multiple {
  background-color: #eee;
  cursor: default;
}
.select2-container--default.select2-container--disabled
  .select2-selection__choice__remove {
  display: none;
}
.select2-container--default.select2-container--open.select2-container--above
  .select2-selection--multiple,
.select2-container--default.select2-container--open.select2-container--above
  .select2-selection--single {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.select2-container--default.select2-container--open.select2-container--below
  .select2-selection--multiple,
.select2-container--default.select2-container--open.select2-container--below
  .select2-selection--single {
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}
.select2-container--default .select2-search--dropdown .select2-search__field {
  border: 1px solid #aaa;
  border: 0.07143rem solid #aaa;
}
.select2-container--default .select2-search--inline .select2-search__field {
  background: 0 0;
  border: none;
  outline: 0;
}
.select2-container--default .select2-results > .select2-results__options {
  max-height: 200px;
  max-height: 14.28571rem;
  overflow-y: auto;
}
.select2-container--default .select2-results__option[role='group'] {
  padding: 0;
}
.select2-container--default .select2-results__option[aria-disabled='true'] {
  color: #999;
}
.select2-container--default .select2-results__option[aria-selected='true'] {
  background-color: #ddd;
}
.select2-container--default .select2-results__option .select2-results__option {
  padding-left: 1em;
}
.select2-container--default
  .select2-results__option
  .select2-results__option
  .select2-results__group {
  padding-left: 0;
}
.select2-container--default
  .select2-results__option
  .select2-results__option
  .select2-results__option {
  margin-left: -1em;
  padding-left: 2em;
}
.select2-container--default
  .select2-results__option
  .select2-results__option
  .select2-results__option
  .select2-results__option {
  margin-left: -2em;
  padding-left: 3em;
}
.select2-container--default
  .select2-results__option
  .select2-results__option
  .select2-results__option
  .select2-results__option
  .select2-results__option {
  margin-left: -3em;
  padding-left: 4em;
}
.select2-container--default
  .select2-results__option
  .select2-results__option
  .select2-results__option
  .select2-results__option
  .select2-results__option
  .select2-results__option {
  margin-left: -4em;
  padding-left: 5em;
}
.select2-container--default
  .select2-results__option
  .select2-results__option
  .select2-results__option
  .select2-results__option
  .select2-results__option
  .select2-results__option
  .select2-results__option {
  margin-left: -5em;
  padding-left: 6em;
}
.select2-container--default
  .select2-results__option--highlighted[aria-selected] {
  background-color: #5897fb;
  color: #fff;
}
.select2-container--default .select2-results__group {
  cursor: default;
  display: block;
  padding: 0.42857rem;
}
.select2-container--classic .select2-selection--single {
  background-color: #f6f6f6;
  border: 1px solid #aaa;
  border: 0.07143rem solid #aaa;
  border-radius: 0.28571rem;
  outline: 0;
  background-image: linear-gradient(to bottom, #fff 50%, #eee 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(
      startColorstr='#ffffff',
      endColorstr='#eeeeee',
      GradientType=0
    );
}
.select2-container--classic .select2-selection--single:focus {
  border: 1px solid #5897fb;
  border: 0.07143rem solid #5897fb;
}
.select2-container--classic
  .select2-selection--single
  .select2-selection__rendered {
  color: #444;
  line-height: 28px;
  line-height: 2rem;
}
.select2-container--classic
  .select2-selection--single
  .select2-selection__clear {
  cursor: pointer;
  float: right;
  font-weight: 700;
  margin-right: 0.71429rem;
}
.select2-container--classic
  .select2-selection--single
  .select2-selection__placeholder {
  color: #999;
}
.select2-container--classic
  .select2-selection--single
  .select2-selection__arrow {
  background-color: #ddd;
  border: none;
  border-left: 1px solid #aaa;
  border-left: 0.07143rem solid #aaa;
  border-top-right-radius: 0.28571rem;
  border-bottom-right-radius: 0.28571rem;
  height: 26px;
  height: 1.85714rem;
  position: absolute;
  top: 1px;
  top: 0.07143rem;
  right: 1px;
  right: 0.07143rem;
  width: 20px;
  width: 1.42857rem;
  background-image: linear-gradient(to bottom, #eee 50%, #ccc 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(
      startColorstr='#eeeeee',
      endColorstr='#cccccc',
      GradientType=0
    );
}
.select2-container--classic
  .select2-selection--single
  .select2-selection__arrow
  b {
  border-color: #888 transparent transparent;
  border-style: solid;
  border-width: 0.35714rem 0.28571rem 0;
  height: 0;
  left: 50%;
  margin-left: -0.28571rem;
  margin-top: -0.14286rem;
  position: absolute;
  top: 50%;
  width: 0;
}
.select2-container--classic[dir='rtl']
  .select2-selection--single
  .select2-selection__clear {
  float: left;
}
.select2-container--classic[dir='rtl']
  .select2-selection--single
  .select2-selection__arrow {
  border: none;
  border-right: 1px solid #aaa;
  border-right: 0.07143rem solid #aaa;
  border-radius: 0.28571rem 0 0 0.28571rem;
  left: 1px;
  left: 0.07143rem;
  right: auto;
}
.select2-container--classic.select2-container--open .select2-selection--single {
  border: 1px solid #5897fb;
  border: 0.07143rem solid #5897fb;
}
.select2-container--classic.select2-container--open
  .select2-selection--single
  .select2-selection__arrow {
  background: 0 0;
  border: none;
}
.select2-container--classic.select2-container--open
  .select2-selection--single
  .select2-selection__arrow
  b {
  border-color: transparent transparent #888;
  border-width: 0 0.28571rem 0.35714rem;
}
.select2-container--classic.select2-container--open.select2-container--above
  .select2-selection--single {
  border-top: none;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  background-image: linear-gradient(to bottom, #fff 0, #eee 50%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(
      startColorstr='#ffffff',
      endColorstr='#eeeeee',
      GradientType=0
    );
}
.select2-container--classic.select2-container--open.select2-container--below
  .select2-selection--single {
  border-bottom: none;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  background-image: linear-gradient(to bottom, #eee 50%, #fff 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(
      startColorstr='#eeeeee',
      endColorstr='#ffffff',
      GradientType=0
    );
}
.select2-container--classic .select2-selection--multiple {
  background-color: #fff;
  border: 1px solid #aaa;
  border: 0.07143rem solid #aaa;
  border-radius: 0.28571rem;
  cursor: text;
  outline: 0;
}
.select2-container--classic .select2-selection--multiple:focus {
  border: 1px solid #5897fb;
  border: 0.07143rem solid #5897fb;
}
.select2-container--classic
  .select2-selection--multiple
  .select2-selection__rendered {
  list-style: none;
  margin: 0;
  padding: 0 0.35714rem;
}
.select2-container--classic
  .select2-selection--multiple
  .select2-selection__clear {
  display: none;
}
.select2-container--classic
  .select2-selection--multiple
  .select2-selection__choice {
  background-color: #e4e4e4;
  border: 1px solid #aaa;
  border: 0.07143rem solid #aaa;
  border-radius: 0.28571rem;
  cursor: default;
  float: left;
  margin-right: 0.35714rem;
  margin-top: 0.35714rem;
  padding: 0 0.35714rem;
}
.select2-container--classic
  .select2-selection--multiple
  .select2-selection__choice__remove {
  color: #888;
  cursor: pointer;
  display: inline-block;
  font-weight: 700;
  margin-right: 0.14286rem;
}
.select2-container--classic
  .select2-selection--multiple
  .select2-selection__choice__remove:hover {
  color: #555;
}
.select2-container--classic[dir='rtl']
  .select2-selection--multiple
  .select2-selection__choice {
  float: right;
  margin-left: 0.35714rem;
  margin-right: auto;
}
.select2-container--classic[dir='rtl']
  .select2-selection--multiple
  .select2-selection__choice__remove {
  margin-left: 0.14286rem;
  margin-right: auto;
}
.select2-container--classic.select2-container--open
  .select2-selection--multiple {
  border: 1px solid #5897fb;
  border: 0.07143rem solid #5897fb;
}
.select2-container--classic.select2-container--open.select2-container--above
  .select2-selection--multiple {
  border-top: none;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.select2-container--classic.select2-container--open.select2-container--below
  .select2-selection--multiple {
  border-bottom: none;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}
.select2-container--classic .select2-search--dropdown .select2-search__field {
  border: 1px solid #aaa;
  border: 0.07143rem solid #aaa;
  outline: 0;
}
.select2-container--classic .select2-search--inline .select2-search__field {
  outline: 0;
}
.select2-container--classic .select2-dropdown {
  background-color: #fff;
  border: 1px solid transparent;
  border: 0.07143rem solid transparent;
}
.select2-container--classic .select2-dropdown--above {
  border-bottom: none;
}
.select2-container--classic .select2-dropdown--below {
  border-top: none;
}
.select2-container--classic .select2-results > .select2-results__options {
  max-height: 200px;
  max-height: 14.28571rem;
  overflow-y: auto;
}
.select2-container--classic .select2-results__option[role='group'] {
  padding: 0;
}
.select2-container--classic .select2-results__option[aria-disabled='true'] {
  color: grey;
}
.select2-container--classic
  .select2-results__option--highlighted[aria-selected] {
  background-color: #3875d7;
  color: #fff;
}
.select2-container--classic .select2-results__group {
  cursor: default;
  display: block;
  padding: 0.42857rem;
}
.select2-container--classic.select2-container--open .select2-dropdown {
  border-color: #5897fb;
} /*!
 * jQuery UI CSS Framework 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/category/theming/
 */ /*!
 * jQuery UI CSS Framework 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/category/theming/
 */ /*!
 * jQuery UI CSS Framework 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/category/theming/
 */
.ui-helper-reset,
.ui-menu {
  outline: 0;
  list-style: none;
}
.ui-helper-hidden {
  display: none;
}
.ui-helper-hidden-accessible {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  height: 0.07143rem;
  margin: -0.07143rem;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px;
  width: 0.07143rem;
}
.ui-helper-zfix,
.ui-widget-overlay {
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}
.ui-helper-reset {
  margin: 0;
  padding: 0;
  border: 0;
  line-height: 1.3;
  text-decoration: none;
  font-size: 100%;
}
.ui-helper-clearfix:after,
.ui-helper-clearfix:before {
  content: '';
  display: table;
  border-collapse: collapse;
}
.ui-helper-clearfix:after {
  clear: both;
}
.ui-helper-clearfix {
  min-height: 0;
}
.ui-helper-zfix {
  position: absolute;
  opacity: 0;
  filter: Alpha(Opacity=0);
}
.ui-front {
  z-index: 100;
}
.ui-state-disabled {
  cursor: default !important;
}
.ui-icon {
  display: block;
  text-indent: -99999px;
  text-indent: -7142.78571rem;
  overflow: hidden;
  background-repeat: no-repeat;
}
.ui-widget-overlay {
  position: fixed;
} /*!
 * jQuery UI Accordion 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/accordion/#theming
 */
.ui-accordion .ui-accordion-header {
  display: block;
  cursor: pointer;
  position: relative;
  margin: 0.14286rem 0 0;
  padding: 0.5em 0.5em 0.5em 0.7em;
  min-height: 0;
  font-size: 100%;
}
.ui-accordion .ui-accordion-icons,
.ui-accordion .ui-accordion-icons .ui-accordion-icons {
  padding-left: 2.2em;
}
.ui-accordion .ui-accordion-header .ui-accordion-header-icon {
  position: absolute;
  left: 0.5em;
  top: 50%;
  margin-top: -0.57143rem;
}
.ui-accordion .ui-accordion-content {
  padding: 1em 2.2em;
  border-top: 0;
  overflow: auto;
} /*!
 * jQuery UI Autocomplete 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/autocomplete/#theming
 */
.ui-autocomplete {
  position: absolute;
  top: 0;
  left: 0;
  cursor: default;
} /*!
 * jQuery UI Button 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/button/#theming
 */
.ui-button {
  display: inline-block;
  position: relative;
  padding: 0;
  line-height: normal;
  margin-right: 0.1em;
  cursor: pointer;
  text-align: center;
  overflow: visible;
}
.ui-button,
.ui-button:active,
.ui-button:hover,
.ui-button:link,
.ui-button:visited {
  text-decoration: none;
}
.ui-button-icon-only {
  width: 2.2em;
}
button.ui-button-icon-only {
  width: 2.4em;
}
.ui-button-icons-only {
  width: 3.4em;
}
button.ui-button-icons-only {
  width: 3.7em;
}
.ui-button .ui-button-text {
  display: block;
  line-height: normal;
}
.ui-button-text-only .ui-button-text {
  padding: 0.4em 1em;
}
.ui-button-icon-only .ui-button-text,
.ui-button-icons-only .ui-button-text {
  padding: 0.4em;
  text-indent: -9999999px;
  text-indent: -714285.64286rem;
}
.ui-button-text-icon-primary .ui-button-text,
.ui-button-text-icons .ui-button-text {
  padding: 0.4em 1em 0.4em 2.1em;
}
.ui-button-text-icon-secondary .ui-button-text,
.ui-button-text-icons .ui-button-text {
  padding: 0.4em 2.1em 0.4em 1em;
}
.ui-button-text-icons .ui-button-text {
  padding-left: 2.1em;
  padding-right: 2.1em;
}
input.ui-button {
  padding: 0.4em 1em;
}
.ui-button-icon-only .ui-icon,
.ui-button-icons-only .ui-icon,
.ui-button-text-icon-primary .ui-icon,
.ui-button-text-icon-secondary .ui-icon,
.ui-button-text-icons .ui-icon {
  position: absolute;
  top: 50%;
  margin-top: -0.57143rem;
}
.ui-button-icon-only .ui-icon {
  left: 50%;
  margin-left: -0.57143rem;
}
.ui-button-icons-only .ui-button-icon-primary,
.ui-button-text-icon-primary .ui-button-icon-primary,
.ui-button-text-icons .ui-button-icon-primary {
  left: 0.5em;
}
.ui-button-icons-only .ui-button-icon-secondary,
.ui-button-text-icon-secondary .ui-button-icon-secondary,
.ui-button-text-icons .ui-button-icon-secondary {
  right: 0.5em;
}
.ui-buttonset {
  margin-right: 0.5rem;
}
.ui-buttonset .ui-button {
  margin-left: 0;
  margin-right: -0.3em;
}
button.ui-button::-moz-focus-inner,
input.ui-button::-moz-focus-inner {
  border: 0;
  padding: 0;
} /*!
 * jQuery UI Datepicker 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/datepicker/#theming
 */
.ui-datepicker {
  width: 17em;
  padding: 0.2em 0.2em 0;
  display: none;
}
.ui-datepicker .ui-datepicker-header {
  position: relative;
  padding: 0.2em 0;
}
.ui-datepicker .ui-datepicker-next,
.ui-datepicker .ui-datepicker-prev {
  position: absolute;
  top: 2px;
  top: 0.14286rem;
  width: 1.8em;
  height: 1.8em;
}
.ui-datepicker .ui-datepicker-next-hover,
.ui-datepicker .ui-datepicker-prev-hover {
  top: 1px;
  top: 0.07143rem;
}
.ui-datepicker .ui-datepicker-prev {
  left: 2px;
  left: 0.14286rem;
}
.ui-datepicker .ui-datepicker-next {
  right: 2px;
  right: 0.14286rem;
}
.ui-datepicker .ui-datepicker-prev-hover {
  left: 1px;
  left: 0.07143rem;
}
.ui-datepicker .ui-datepicker-next-hover {
  right: 1px;
  right: 0.07143rem;
}
.ui-datepicker .ui-datepicker-next span,
.ui-datepicker .ui-datepicker-prev span {
  display: block;
  position: absolute;
  left: 50%;
  margin-left: -0.57143rem;
  top: 50%;
  margin-top: -0.57143rem;
}
.ui-datepicker .ui-datepicker-title {
  margin: 0 2.3em;
  line-height: 1.8em;
  text-align: center;
}
.ui-datepicker .ui-datepicker-title select {
  font-size: 1em;
  margin: 0.07143rem 0;
}
.ui-datepicker select.ui-datepicker-month,
.ui-datepicker select.ui-datepicker-year {
  width: 45%;
}
.ui-datepicker table {
  width: 100%;
  font-size: 0.9em;
  border-collapse: collapse;
  margin: 0 0 0.4em;
}
.ui-datepicker th {
  padding: 0.7em 0.3em;
  text-align: center;
  font-weight: 700;
  border: 0;
}
.ui-datepicker td {
  border: 0;
  padding: 0.07143rem;
}
.ui-datepicker td a,
.ui-datepicker td span {
  display: block;
  padding: 0.2em;
  text-align: right;
  text-decoration: none;
}
.ui-datepicker .ui-datepicker-buttonpane {
  background-image: none;
  margin: 0.7em 0 0;
  padding: 0 0.2em;
  border-left: 0;
  border-right: 0;
  border-bottom: 0;
}
.ui-datepicker .ui-datepicker-buttonpane button {
  float: right;
  margin: 0.5em 0.2em 0.4em;
  cursor: pointer;
  padding: 0.2em 0.6em 0.3em;
  width: auto;
  overflow: visible;
}
.ui-datepicker .ui-datepicker-buttonpane button.ui-datepicker-current,
.ui-datepicker-multi .ui-datepicker-group,
.ui-datepicker-rtl .ui-datepicker-buttonpane button {
  float: left;
}
.ui-datepicker.ui-datepicker-multi {
  width: auto;
}
.ui-datepicker-multi .ui-datepicker-group table {
  width: 95%;
  margin: 0 auto 0.4em;
}
.ui-datepicker-multi-2 .ui-datepicker-group {
  width: 50%;
}
.ui-datepicker-multi-3 .ui-datepicker-group {
  width: 33.3%;
}
.ui-datepicker-multi-4 .ui-datepicker-group {
  width: 25%;
}
.ui-datepicker-multi .ui-datepicker-group-last .ui-datepicker-header,
.ui-datepicker-multi .ui-datepicker-group-middle .ui-datepicker-header {
  border-left-width: 0;
}
.ui-datepicker-multi .ui-datepicker-buttonpane {
  clear: left;
}
.ui-datepicker-row-break {
  clear: both;
  width: 100%;
  font-size: 0;
}
.ui-datepicker-rtl {
  direction: rtl;
}
.ui-datepicker-rtl .ui-datepicker-prev {
  right: 2px;
  right: 0.14286rem;
  left: auto;
}
.ui-datepicker-rtl .ui-datepicker-next {
  left: 2px;
  left: 0.14286rem;
  right: auto;
}
.ui-datepicker-rtl .ui-datepicker-prev:hover {
  right: 1px;
  right: 0.07143rem;
  left: auto;
}
.ui-datepicker-rtl .ui-datepicker-next:hover {
  left: 1px;
  left: 0.07143rem;
  right: auto;
}
.ui-datepicker-rtl .ui-datepicker-buttonpane {
  clear: right;
}
.ui-datepicker-rtl .ui-datepicker-buttonpane button.ui-datepicker-current,
.ui-datepicker-rtl .ui-datepicker-group {
  float: right;
}
.ui-datepicker-rtl .ui-datepicker-group-last .ui-datepicker-header,
.ui-datepicker-rtl .ui-datepicker-group-middle .ui-datepicker-header {
  border-right-width: 0;
  border-left-width: 0.07143rem;
} /*!
 * jQuery UI Dialog 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/dialog/#theming
 */
.ui-dialog {
  overflow: hidden;
  position: absolute;
  top: 0;
  left: 0;
  padding: 0.2em;
  outline: 0;
}
.ui-dialog .ui-dialog-titlebar {
  padding: 0.4em 1em;
  position: relative;
}
.ui-dialog .ui-dialog-title {
  float: left;
  margin: 0.1em 0;
  white-space: nowrap;
  width: 90%;
  overflow: hidden;
  text-overflow: ellipsis;
}
.ui-dialog .ui-dialog-titlebar-close {
  position: absolute;
  right: 0.3em;
  top: 50%;
  width: 20px;
  width: 1.42857rem;
  margin: -0.71429rem 0 0;
  padding: 0.07143rem;
  height: 20px;
  height: 1.42857rem;
}
.ui-dialog .ui-dialog-content {
  position: relative;
  border: 0;
  padding: 0.5em 1em;
  background: 0 0;
  overflow: auto;
}
.ui-dialog .ui-dialog-buttonpane {
  text-align: left;
  border-width: 0.07143rem 0 0;
  background-image: none;
  margin-top: 0.5em;
  padding: 0.3em 1em 0.5em 0.4em;
}
.ui-dialog .ui-dialog-buttonpane .ui-dialog-buttonset {
  float: right;
}
.ui-dialog .ui-dialog-buttonpane button {
  margin: 0.5em 0.4em 0.5em 0;
  cursor: pointer;
}
.ui-dialog .ui-resizable-se {
  width: 12px;
  width: 0.85714rem;
  height: 12px;
  height: 0.85714rem;
  right: -5px;
  right: -0.35714rem;
  bottom: -5px;
  bottom: -0.35714rem;
  background-position: 1.14286rem 1.14286rem;
}
.ui-draggable .ui-dialog-titlebar {
  cursor: move;
} /*!
 * jQuery UI Draggable 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 */
.ui-draggable-handle {
  -ms-touch-action: none;
  touch-action: none;
} /*!
 * jQuery UI Menu 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/menu/#theming
 */
.ui-menu {
  padding: 0;
  margin: 0;
  display: block;
}
.ui-menu .ui-menu {
  position: absolute;
}
.ui-menu .ui-menu-item {
  position: relative;
  margin: 0;
  padding: 0.21429rem 1em 0.21429rem 0.4em;
  cursor: pointer;
  min-height: 0;
  list-style-image: url(data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7);
}
.ui-menu .ui-menu-divider {
  margin: 0.35714rem 0;
  height: 0;
  font-size: 0;
  line-height: 0;
  border-width: 0.07143rem 0 0;
}
.ui-menu .ui-state-active,
.ui-menu .ui-state-focus {
  margin: -0.07143rem;
}
.ui-menu-icons {
  position: relative;
}
.ui-menu-icons .ui-menu-item {
  padding-left: 2em;
}
.ui-menu .ui-icon {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0.2em;
  margin: auto 0;
}
.ui-menu .ui-menu-icon {
  left: auto;
  right: 0;
} /*!
 * jQuery UI Progressbar 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/progressbar/#theming
 */
.ui-progressbar {
  height: 2em;
  text-align: left;
  overflow: hidden;
}
.ui-progressbar .ui-progressbar-value {
  margin: -0.07143rem;
  height: 100%;
}
.ui-progressbar .ui-progressbar-overlay {
  background: url(data:image/gif;base64,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);
  height: 100%;
  filter: alpha(opacity=25);
  opacity: 0.25;
}
.ui-progressbar-indeterminate .ui-progressbar-value {
  background-image: none;
} /*!
 * jQuery UI Resizable 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 */
.ui-resizable {
  position: relative;
}
.ui-resizable-handle {
  position: absolute;
  font-size: 0.1px;
  font-size: 0.00714rem;
  display: block;
  -ms-touch-action: none;
  touch-action: none;
}
.ui-resizable-autohide .ui-resizable-handle,
.ui-resizable-disabled .ui-resizable-handle {
  display: none;
}
.ui-resizable-n {
  cursor: n-resize;
  height: 7px;
  height: 0.5rem;
  width: 100%;
  top: -5px;
  top: -0.35714rem;
  left: 0;
}
.ui-resizable-s {
  cursor: s-resize;
  height: 7px;
  height: 0.5rem;
  width: 100%;
  bottom: -5px;
  bottom: -0.35714rem;
  left: 0;
}
.ui-resizable-e {
  cursor: e-resize;
  width: 7px;
  width: 0.5rem;
  right: -5px;
  right: -0.35714rem;
  top: 0;
  height: 100%;
}
.ui-resizable-w {
  cursor: w-resize;
  width: 7px;
  width: 0.5rem;
  left: -5px;
  left: -0.35714rem;
  top: 0;
  height: 100%;
}
.ui-resizable-se {
  cursor: se-resize;
  width: 12px;
  width: 0.85714rem;
  height: 12px;
  height: 0.85714rem;
  right: 1px;
  right: 0.07143rem;
  bottom: 1px;
  bottom: 0.07143rem;
}
.ui-resizable-sw {
  cursor: sw-resize;
  width: 9px;
  width: 0.64286rem;
  height: 9px;
  height: 0.64286rem;
  left: -5px;
  left: -0.35714rem;
  bottom: -5px;
  bottom: -0.35714rem;
}
.ui-slider-vertical .ui-slider-range-min,
.ui-spinner-down {
  bottom: 0;
}
.ui-resizable-nw {
  cursor: nw-resize;
  width: 9px;
  width: 0.64286rem;
  height: 9px;
  height: 0.64286rem;
  left: -5px;
  left: -0.35714rem;
  top: -5px;
  top: -0.35714rem;
}
.ui-resizable-ne {
  cursor: ne-resize;
  width: 9px;
  width: 0.64286rem;
  height: 9px;
  height: 0.64286rem;
  right: -5px;
  right: -0.35714rem;
  top: -5px;
  top: -0.35714rem;
} /*!
 * jQuery UI Selectable 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 */
.ui-selectable {
  -ms-touch-action: none;
  touch-action: none;
}
.ui-selectable-helper {
  position: absolute;
  z-index: 100;
  border: 1px dotted #000;
  border: 0.07143rem dotted #000;
} /*!
 * jQuery UI Selectmenu 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/selectmenu/#theming
 */
.ui-selectmenu-menu {
  padding: 0;
  margin: 0;
  position: absolute;
  top: 0;
  left: 0;
  display: none;
}
.ui-selectmenu-menu .ui-menu {
  overflow: auto;
  overflow-x: hidden;
  padding-bottom: 0.07143rem;
}
.ui-selectmenu-menu .ui-menu .ui-selectmenu-optgroup {
  font-size: 1em;
  font-weight: 700;
  line-height: 1.5;
  padding: 0.14286rem 0.4em;
  margin: 0.5em 0 0;
  height: auto;
  border: 0;
}
.ui-selectmenu-open {
  display: block;
}
.ui-selectmenu-button {
  display: inline-block;
  overflow: hidden;
  position: relative;
  text-decoration: none;
  cursor: pointer;
}
.ui-selectmenu-button span.ui-icon {
  right: 0.5em;
  left: auto;
  margin-top: -0.57143rem;
  position: absolute;
  top: 50%;
}
.ui-selectmenu-button span.ui-selectmenu-text {
  text-align: left;
  padding: 0.4em 2.1em 0.4em 1em;
  display: block;
  line-height: 1.4;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
} /*!
 * jQuery UI Sortable 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 */
.ui-sortable-handle {
  -ms-touch-action: none;
  touch-action: none;
} /*!
 * jQuery UI Slider 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/slider/#theming
 */
.ui-slider {
  position: relative;
  text-align: left;
}
.ui-slider .ui-slider-handle {
  position: absolute;
  z-index: 2;
  width: 1.2em;
  height: 1.2em;
  cursor: default;
  -ms-touch-action: none;
  touch-action: none;
}
.ui-slider .ui-slider-range {
  position: absolute;
  z-index: 1;
  font-size: 0.7em;
  display: block;
  border: 0;
  background-position: 0 0;
}
.ui-slider.ui-state-disabled .ui-slider-handle,
.ui-slider.ui-state-disabled .ui-slider-range {
  -webkit-filter: inherit;
  filter: inherit;
}
.ui-slider-horizontal {
  height: 0.8em;
}
.ui-slider-horizontal .ui-slider-handle {
  top: -0.3em;
  margin-left: -0.6em;
}
.ui-slider-horizontal .ui-slider-range {
  top: 0;
  height: 100%;
}
.ui-slider-horizontal .ui-slider-range-min {
  left: 0;
}
.ui-slider-horizontal .ui-slider-range-max {
  right: 0;
}
.ui-slider-vertical {
  width: 0.8em;
  height: 100px;
  height: 7.14286rem;
}
.ui-slider-vertical .ui-slider-handle {
  left: -0.3em;
  margin-left: 0;
  margin-bottom: -0.6em;
}
.ui-slider-vertical .ui-slider-range {
  left: 0;
  width: 100%;
}
.ui-slider-vertical .ui-slider-range-max {
  top: 0;
} /*!
 * jQuery UI Spinner 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/spinner/#theming
 */
.ui-spinner {
  position: relative;
  display: inline-block;
  overflow: hidden;
  padding: 0;
}
.ui-spinner-input {
  border: none;
  background: 0 0;
  color: inherit;
  padding: 0;
  margin: 0.2em 1.57143rem 0.2em 0.4em;
}
.ui-widget-content a,
.ui-widget-header,
.ui-widget-header a {
  color: #222;
}
.ui-spinner-button {
  width: 16px;
  width: 1.14286rem;
  height: 50%;
  font-size: 0.5em;
  padding: 0;
  margin: 0;
  text-align: center;
  position: absolute;
  cursor: default;
  display: block;
  overflow: hidden;
  right: 0;
}
.ui-spinner a.ui-spinner-button {
  border-top: none;
  border-bottom: none;
  border-right: none;
}
.ui-spinner .ui-icon {
  position: absolute;
  margin-top: -0.57143rem;
  top: 50%;
  left: 0;
}
.ui-spinner-up {
  top: 0;
}
.ui-spinner .ui-icon-triangle-1-s {
  background-position: -4.64286rem -1.14286rem;
} /*!
 * jQuery UI Tabs 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/tabs/#theming
 */
.ui-tabs {
  position: relative;
  padding: 0.2em;
}
.ui-tabs .ui-tabs-nav {
  margin: 0;
  padding: 0.2em 0.2em 0;
}
.ui-tabs .ui-tabs-nav li {
  list-style: none;
  float: left;
  position: relative;
  top: 0;
  margin: 0.07143rem 0.2em 0 0;
  border-bottom-width: 0;
  padding: 0;
  white-space: nowrap;
}
.ui-tabs .ui-tabs-nav .ui-tabs-anchor {
  float: left;
  padding: 0.5em 1em;
  text-decoration: none;
}
.ui-tabs .ui-tabs-nav li.ui-tabs-active {
  margin-bottom: -0.07143rem;
  padding-bottom: 0.07143rem;
}
.ui-tabs .ui-tabs-nav li.ui-state-disabled .ui-tabs-anchor,
.ui-tabs .ui-tabs-nav li.ui-tabs-active .ui-tabs-anchor,
.ui-tabs .ui-tabs-nav li.ui-tabs-loading .ui-tabs-anchor {
  cursor: text;
}
.ui-tabs-collapsible .ui-tabs-nav li.ui-tabs-active .ui-tabs-anchor,
.ui-timepicker-table td a {
  cursor: pointer;
}
.ui-tabs .ui-tabs-panel {
  display: block;
  border-width: 0;
  padding: 1em 1.4em;
  background: 0 0;
} /*!
 * jQuery UI Tooltip 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/tooltip/#theming
 */
.ui-tooltip {
  padding: 0.57143rem;
  position: absolute;
  z-index: 9999;
  max-width: 300px;
  max-width: 21.42857rem;
  box-shadow: 0 0 5px #aaa;
  box-shadow: 0 0 0.35714rem #aaa;
}
body .ui-tooltip {
  border-width: 0.14286rem;
} /*!
 * jQuery UI CSS Framework 1.11.4
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/category/theming/
 *
 * To view and modify this theme, visit http://jqueryui.com/themeroller/
 */
.ui-widget {
  font-family: Verdana, Arial, sans-serif;
  font-size: 1.1em;
}
.ui-widget .ui-widget {
  font-size: 1em;
}
.ui-widget button,
.ui-widget input,
.ui-widget select,
.ui-widget textarea {
  font-family: Verdana, Arial, sans-serif;
  font-size: 1em;
}
.ui-widget-content {
  border: 1px solid #aaa;
  border: 0.07143rem solid #aaa;
  background: url(jquery-ui/images/ui-bg_flat_75_ffffff_40x100.png) 50% 50%
    repeat-x #fff;
  color: #222;
}
.ui-widget-header {
  border: 1px solid #aaa;
  border: 0.07143rem solid #aaa;
  background: url(jquery-ui/images/ui-bg_highlight-soft_75_cccccc_1x100.png) 50%
    50% repeat-x #ccc;
  font-weight: 700;
}
.ui-state-default,
.ui-widget-content .ui-state-default,
.ui-widget-header .ui-state-default {
  border: 1px solid #d3d3d3;
  border: 0.07143rem solid #d3d3d3;
  background: url(jquery-ui/images/ui-bg_glass_75_e6e6e6_1x400.png) 50% 50%
    repeat-x #e6e6e6;
  font-weight: 400;
  color: #555;
}
.ui-state-default a,
.ui-state-default a:link,
.ui-state-default a:visited {
  color: #555;
  text-decoration: none;
}
.ui-state-focus,
.ui-state-hover,
.ui-widget-content .ui-state-focus,
.ui-widget-content .ui-state-hover,
.ui-widget-header .ui-state-focus,
.ui-widget-header .ui-state-hover {
  border: 1px solid #999;
  border: 0.07143rem solid #999;
  background: url(jquery-ui/images/ui-bg_glass_75_dadada_1x400.png) 50% 50%
    repeat-x #dadada;
  font-weight: 400;
  color: #212121;
}
.ui-state-focus a,
.ui-state-focus a:hover,
.ui-state-focus a:link,
.ui-state-focus a:visited,
.ui-state-hover a,
.ui-state-hover a:hover,
.ui-state-hover a:link,
.ui-state-hover a:visited {
  color: #212121;
  text-decoration: none;
}
.ui-state-active,
.ui-widget-content .ui-state-active,
.ui-widget-header .ui-state-active {
  border: 1px solid #aaa;
  border: 0.07143rem solid #aaa;
  background: url(jquery-ui/images/ui-bg_glass_65_ffffff_1x400.png) 50% 50%
    repeat-x #fff;
  font-weight: 400;
  color: #212121;
}
.ui-state-active a,
.ui-state-active a:link,
.ui-state-active a:visited {
  color: #212121;
  text-decoration: none;
}
.ui-state-highlight,
.ui-widget-content .ui-state-highlight,
.ui-widget-header .ui-state-highlight {
  border: 1px solid #fcefa1;
  border: 0.07143rem solid #fcefa1;
  background: url(jquery-ui/images/ui-bg_glass_55_fbf9ee_1x400.png) 50% 50%
    repeat-x #fbf9ee;
  color: #363636;
}
.ui-state-highlight a,
.ui-widget-content .ui-state-highlight a,
.ui-widget-header .ui-state-highlight a {
  color: #363636;
}
.ui-state-error,
.ui-widget-content .ui-state-error,
.ui-widget-header .ui-state-error {
  border: 1px solid #cd0a0a;
  border: 0.07143rem solid #cd0a0a;
  background: url(jquery-ui/images/ui-bg_glass_95_fef1ec_1x400.png) 50% 50%
    repeat-x #fef1ec;
  color: #cd0a0a;
}
.ui-state-error a,
.ui-state-error-text,
.ui-widget-content .ui-state-error a,
.ui-widget-content .ui-state-error-text,
.ui-widget-header .ui-state-error a,
.ui-widget-header .ui-state-error-text {
  color: #cd0a0a;
}
.ui-priority-primary,
.ui-widget-content .ui-priority-primary,
.ui-widget-header .ui-priority-primary {
  font-weight: 700;
}
.ui-priority-secondary,
.ui-widget-content .ui-priority-secondary,
.ui-widget-header .ui-priority-secondary {
  opacity: 0.7;
  filter: Alpha(Opacity=70);
  font-weight: 400;
}
.ui-state-disabled,
.ui-widget-content .ui-state-disabled,
.ui-widget-header .ui-state-disabled {
  opacity: 0.35;
  filter: Alpha(Opacity=35);
  background-image: none;
}
.ui-state-disabled .ui-icon {
  filter: Alpha(Opacity=35);
}
.ui-icon {
  width: 16px;
  width: 1.14286rem;
  height: 16px;
  height: 1.14286rem;
}
.ui-icon,
.ui-widget-content .ui-icon,
.ui-widget-header .ui-icon {
  background-image: url(jquery-ui/images/ui-icons_222222_256x240.png);
}
.ui-state-default .ui-icon {
  background-image: url(jquery-ui/images/ui-icons_888888_256x240.png);
}
.ui-state-active .ui-icon,
.ui-state-focus .ui-icon,
.ui-state-hover .ui-icon {
  background-image: url(jquery-ui/images/ui-icons_454545_256x240.png);
}
.ui-state-highlight .ui-icon {
  background-image: url(jquery-ui/images/ui-icons_2e83ff_256x240.png);
}
.ui-state-error .ui-icon,
.ui-state-error-text .ui-icon {
  background-image: url(jquery-ui/images/ui-icons_cd0a0a_256x240.png);
}
.ui-icon-blank {
  background-position: 1.14286rem 1.14286rem;
}
.ui-icon-carat-1-n {
  background-position: 0 0;
}
.ui-icon-carat-1-ne {
  background-position: -1.14286rem 0;
}
.ui-icon-carat-1-e {
  background-position: -2.28571rem 0;
}
.ui-icon-carat-1-se {
  background-position: -3.42857rem 0;
}
.ui-icon-carat-1-s {
  background-position: -4.57143rem 0;
}
.ui-icon-carat-1-sw {
  background-position: -5.71429rem 0;
}
.ui-icon-carat-1-w {
  background-position: -6.85714rem 0;
}
.ui-icon-carat-1-nw {
  background-position: -8rem 0;
}
.ui-icon-carat-2-n-s {
  background-position: -9.14286rem 0;
}
.ui-icon-carat-2-e-w {
  background-position: -10.28571rem 0;
}
.ui-icon-triangle-1-n {
  background-position: 0 -1.14286rem;
}
.ui-icon-triangle-1-ne {
  background-position: -1.14286rem -1.14286rem;
}
.ui-icon-triangle-1-e {
  background-position: -2.28571rem -1.14286rem;
}
.ui-icon-triangle-1-se {
  background-position: -3.42857rem -1.14286rem;
}
.ui-icon-triangle-1-s {
  background-position: -4.57143rem -1.14286rem;
}
.ui-icon-triangle-1-sw {
  background-position: -5.71429rem -1.14286rem;
}
.ui-icon-triangle-1-w {
  background-position: -6.85714rem -1.14286rem;
}
.ui-icon-triangle-1-nw {
  background-position: -8rem -1.14286rem;
}
.ui-icon-triangle-2-n-s {
  background-position: -9.14286rem -1.14286rem;
}
.ui-icon-triangle-2-e-w {
  background-position: -10.28571rem -1.14286rem;
}
.ui-icon-arrow-1-n {
  background-position: 0 -2.28571rem;
}
.ui-icon-arrow-1-ne {
  background-position: -1.14286rem -2.28571rem;
}
.ui-icon-arrow-1-e {
  background-position: -2.28571rem -2.28571rem;
}
.ui-icon-arrow-1-se {
  background-position: -3.42857rem -2.28571rem;
}
.ui-icon-arrow-1-s {
  background-position: -4.57143rem -2.28571rem;
}
.ui-icon-arrow-1-sw {
  background-position: -5.71429rem -2.28571rem;
}
.ui-icon-arrow-1-w {
  background-position: -6.85714rem -2.28571rem;
}
.ui-icon-arrow-1-nw {
  background-position: -8rem -2.28571rem;
}
.ui-icon-arrow-2-n-s {
  background-position: -9.14286rem -2.28571rem;
}
.ui-icon-arrow-2-ne-sw {
  background-position: -10.28571rem -2.28571rem;
}
.ui-icon-arrow-2-e-w {
  background-position: -11.42857rem -2.28571rem;
}
.ui-icon-arrow-2-se-nw {
  background-position: -12.57143rem -2.28571rem;
}
.ui-icon-arrowstop-1-n {
  background-position: -13.71429rem -2.28571rem;
}
.ui-icon-arrowstop-1-e {
  background-position: -14.85714rem -2.28571rem;
}
.ui-icon-arrowstop-1-s {
  background-position: -16rem -2.28571rem;
}
.ui-icon-arrowstop-1-w {
  background-position: -17.14286rem -2.28571rem;
}
.ui-icon-arrowthick-1-n {
  background-position: 0 -3.42857rem;
}
.ui-icon-arrowthick-1-ne {
  background-position: -1.14286rem -3.42857rem;
}
.ui-icon-arrowthick-1-e {
  background-position: -2.28571rem -3.42857rem;
}
.ui-icon-arrowthick-1-se {
  background-position: -3.42857rem -3.42857rem;
}
.ui-icon-arrowthick-1-s {
  background-position: -4.57143rem -3.42857rem;
}
.ui-icon-arrowthick-1-sw {
  background-position: -5.71429rem -3.42857rem;
}
.ui-icon-arrowthick-1-w {
  background-position: -6.85714rem -3.42857rem;
}
.ui-icon-arrowthick-1-nw {
  background-position: -8rem -3.42857rem;
}
.ui-icon-arrowthick-2-n-s {
  background-position: -9.14286rem -3.42857rem;
}
.ui-icon-arrowthick-2-ne-sw {
  background-position: -10.28571rem -3.42857rem;
}
.ui-icon-arrowthick-2-e-w {
  background-position: -11.42857rem -3.42857rem;
}
.ui-icon-arrowthick-2-se-nw {
  background-position: -12.57143rem -3.42857rem;
}
.ui-icon-arrowthickstop-1-n {
  background-position: -13.71429rem -3.42857rem;
}
.ui-icon-arrowthickstop-1-e {
  background-position: -14.85714rem -3.42857rem;
}
.ui-icon-arrowthickstop-1-s {
  background-position: -16rem -3.42857rem;
}
.ui-icon-arrowthickstop-1-w {
  background-position: -17.14286rem -3.42857rem;
}
.ui-icon-arrowreturnthick-1-w {
  background-position: 0 -4.57143rem;
}
.ui-icon-arrowreturnthick-1-n {
  background-position: -1.14286rem -4.57143rem;
}
.ui-icon-arrowreturnthick-1-e {
  background-position: -2.28571rem -4.57143rem;
}
.ui-icon-arrowreturnthick-1-s {
  background-position: -3.42857rem -4.57143rem;
}
.ui-icon-arrowreturn-1-w {
  background-position: -4.57143rem -4.57143rem;
}
.ui-icon-arrowreturn-1-n {
  background-position: -5.71429rem -4.57143rem;
}
.ui-icon-arrowreturn-1-e {
  background-position: -6.85714rem -4.57143rem;
}
.ui-icon-arrowreturn-1-s {
  background-position: -8rem -4.57143rem;
}
.ui-icon-arrowrefresh-1-w {
  background-position: -9.14286rem -4.57143rem;
}
.ui-icon-arrowrefresh-1-n {
  background-position: -10.28571rem -4.57143rem;
}
.ui-icon-arrowrefresh-1-e {
  background-position: -11.42857rem -4.57143rem;
}
.ui-icon-arrowrefresh-1-s {
  background-position: -12.57143rem -4.57143rem;
}
.ui-icon-arrow-4 {
  background-position: 0 -5.71429rem;
}
.ui-icon-arrow-4-diag {
  background-position: -1.14286rem -5.71429rem;
}
.ui-icon-extlink {
  background-position: -2.28571rem -5.71429rem;
}
.ui-icon-newwin {
  background-position: -3.42857rem -5.71429rem;
}
.ui-icon-refresh {
  background-position: -4.57143rem -5.71429rem;
}
.ui-icon-shuffle {
  background-position: -5.71429rem -5.71429rem;
}
.ui-icon-transfer-e-w {
  background-position: -6.85714rem -5.71429rem;
}
.ui-icon-transferthick-e-w {
  background-position: -8rem -5.71429rem;
}
.ui-icon-folder-collapsed {
  background-position: 0 -6.85714rem;
}
.ui-icon-folder-open {
  background-position: -1.14286rem -6.85714rem;
}
.ui-icon-document {
  background-position: -2.28571rem -6.85714rem;
}
.ui-icon-document-b {
  background-position: -3.42857rem -6.85714rem;
}
.ui-icon-note {
  background-position: -4.57143rem -6.85714rem;
}
.ui-icon-mail-closed {
  background-position: -5.71429rem -6.85714rem;
}
.ui-icon-mail-open {
  background-position: -6.85714rem -6.85714rem;
}
.ui-icon-suitcase {
  background-position: -8rem -6.85714rem;
}
.ui-icon-comment {
  background-position: -9.14286rem -6.85714rem;
}
.ui-icon-person {
  background-position: -10.28571rem -6.85714rem;
}
.ui-icon-print {
  background-position: -11.42857rem -6.85714rem;
}
.ui-icon-trash {
  background-position: -12.57143rem -6.85714rem;
}
.ui-icon-locked {
  background-position: -13.71429rem -6.85714rem;
}
.ui-icon-unlocked {
  background-position: -14.85714rem -6.85714rem;
}
.ui-icon-bookmark {
  background-position: -16rem -6.85714rem;
}
.ui-icon-tag {
  background-position: -17.14286rem -6.85714rem;
}
.ui-icon-home {
  background-position: 0 -8rem;
}
.ui-icon-flag {
  background-position: -1.14286rem -8rem;
}
.ui-icon-calendar {
  background-position: -2.28571rem -8rem;
}
.ui-icon-cart {
  background-position: -3.42857rem -8rem;
}
.ui-icon-pencil {
  background-position: -4.57143rem -8rem;
}
.ui-icon-clock {
  background-position: -5.71429rem -8rem;
}
.ui-icon-disk {
  background-position: -6.85714rem -8rem;
}
.ui-icon-calculator {
  background-position: -8rem -8rem;
}
.ui-icon-zoomin {
  background-position: -9.14286rem -8rem;
}
.ui-icon-zoomout {
  background-position: -10.28571rem -8rem;
}
.ui-icon-search {
  background-position: -11.42857rem -8rem;
}
.ui-icon-wrench {
  background-position: -12.57143rem -8rem;
}
.ui-icon-gear {
  background-position: -13.71429rem -8rem;
}
.ui-icon-heart {
  background-position: -14.85714rem -8rem;
}
.ui-icon-star {
  background-position: -16rem -8rem;
}
.ui-icon-link {
  background-position: -17.14286rem -8rem;
}
.ui-icon-cancel {
  background-position: 0 -9.14286rem;
}
.ui-icon-plus {
  background-position: -1.14286rem -9.14286rem;
}
.ui-icon-plusthick {
  background-position: -2.28571rem -9.14286rem;
}
.ui-icon-minus {
  background-position: -3.42857rem -9.14286rem;
}
.ui-icon-minusthick {
  background-position: -4.57143rem -9.14286rem;
}
.ui-icon-close {
  background-position: -5.71429rem -9.14286rem;
}
.ui-icon-closethick {
  background-position: -6.85714rem -9.14286rem;
}
.ui-icon-key {
  background-position: -8rem -9.14286rem;
}
.ui-icon-lightbulb {
  background-position: -9.14286rem -9.14286rem;
}
.ui-icon-scissors {
  background-position: -10.28571rem -9.14286rem;
}
.ui-icon-clipboard {
  background-position: -11.42857rem -9.14286rem;
}
.ui-icon-copy {
  background-position: -12.57143rem -9.14286rem;
}
.ui-icon-contact {
  background-position: -13.71429rem -9.14286rem;
}
.ui-icon-image {
  background-position: -14.85714rem -9.14286rem;
}
.ui-icon-video {
  background-position: -16rem -9.14286rem;
}
.ui-icon-script {
  background-position: -17.14286rem -9.14286rem;
}
.ui-icon-alert {
  background-position: 0 -10.28571rem;
}
.ui-icon-info {
  background-position: -1.14286rem -10.28571rem;
}
.ui-icon-notice {
  background-position: -2.28571rem -10.28571rem;
}
.ui-icon-help {
  background-position: -3.42857rem -10.28571rem;
}
.ui-icon-check {
  background-position: -4.57143rem -10.28571rem;
}
.ui-icon-bullet {
  background-position: -5.71429rem -10.28571rem;
}
.ui-icon-radio-on {
  background-position: -6.85714rem -10.28571rem;
}
.ui-icon-radio-off {
  background-position: -8rem -10.28571rem;
}
.ui-icon-pin-w {
  background-position: -9.14286rem -10.28571rem;
}
.ui-icon-pin-s {
  background-position: -10.28571rem -10.28571rem;
}
.ui-icon-play {
  background-position: 0 -11.42857rem;
}
.ui-icon-pause {
  background-position: -1.14286rem -11.42857rem;
}
.ui-icon-seek-next {
  background-position: -2.28571rem -11.42857rem;
}
.ui-icon-seek-prev {
  background-position: -3.42857rem -11.42857rem;
}
.ui-icon-seek-end {
  background-position: -4.57143rem -11.42857rem;
}
.ui-icon-seek-first,
.ui-icon-seek-start {
  background-position: -5.71429rem -11.42857rem;
}
.ui-icon-stop {
  background-position: -6.85714rem -11.42857rem;
}
.ui-icon-eject {
  background-position: -8rem -11.42857rem;
}
.ui-icon-volume-off {
  background-position: -9.14286rem -11.42857rem;
}
.ui-icon-volume-on {
  background-position: -10.28571rem -11.42857rem;
}
.ui-icon-power {
  background-position: 0 -12.57143rem;
}
.ui-icon-signal-diag {
  background-position: -1.14286rem -12.57143rem;
}
.ui-icon-signal {
  background-position: -2.28571rem -12.57143rem;
}
.ui-icon-battery-0 {
  background-position: -3.42857rem -12.57143rem;
}
.ui-icon-battery-1 {
  background-position: -4.57143rem -12.57143rem;
}
.ui-icon-battery-2 {
  background-position: -5.71429rem -12.57143rem;
}
.ui-icon-battery-3 {
  background-position: -6.85714rem -12.57143rem;
}
.ui-icon-circle-plus {
  background-position: 0 -13.71429rem;
}
.ui-icon-circle-minus {
  background-position: -1.14286rem -13.71429rem;
}
.ui-icon-circle-close {
  background-position: -2.28571rem -13.71429rem;
}
.ui-icon-circle-triangle-e {
  background-position: -3.42857rem -13.71429rem;
}
.ui-icon-circle-triangle-s {
  background-position: -4.57143rem -13.71429rem;
}
.ui-icon-circle-triangle-w {
  background-position: -5.71429rem -13.71429rem;
}
.ui-icon-circle-triangle-n {
  background-position: -6.85714rem -13.71429rem;
}
.ui-icon-circle-arrow-e {
  background-position: -8rem -13.71429rem;
}
.ui-icon-circle-arrow-s {
  background-position: -9.14286rem -13.71429rem;
}
.ui-icon-circle-arrow-w {
  background-position: -10.28571rem -13.71429rem;
}
.ui-icon-circle-arrow-n {
  background-position: -11.42857rem -13.71429rem;
}
.ui-icon-circle-zoomin {
  background-position: -12.57143rem -13.71429rem;
}
.ui-icon-circle-zoomout {
  background-position: -13.71429rem -13.71429rem;
}
.ui-icon-circle-check {
  background-position: -14.85714rem -13.71429rem;
}
.ui-icon-circlesmall-plus {
  background-position: 0 -14.85714rem;
}
.ui-icon-circlesmall-minus {
  background-position: -1.14286rem -14.85714rem;
}
.ui-icon-circlesmall-close {
  background-position: -2.28571rem -14.85714rem;
}
.ui-icon-squaresmall-plus {
  background-position: -3.42857rem -14.85714rem;
}
.ui-icon-squaresmall-minus {
  background-position: -4.57143rem -14.85714rem;
}
.ui-icon-squaresmall-close {
  background-position: -5.71429rem -14.85714rem;
}
.ui-icon-grip-dotted-vertical {
  background-position: 0 -16rem;
}
.ui-icon-grip-dotted-horizontal {
  background-position: -1.14286rem -16rem;
}
.ui-icon-grip-solid-vertical {
  background-position: -2.28571rem -16rem;
}
.ui-icon-grip-solid-horizontal {
  background-position: -3.42857rem -16rem;
}
.ui-icon-gripsmall-diagonal-se {
  background-position: -4.57143rem -16rem;
}
.ui-icon-grip-diagonal-se {
  background-position: -5.71429rem -16rem;
}
.ui-widget-overlay,
.ui-widget-shadow {
  background: url(jquery-ui/images/ui-bg_flat_0_aaaaaa_40x100.png) 50% 50%
    repeat-x #aaa;
  opacity: 0.3;
  filter: Alpha(Opacity=30);
}
.ui-corner-all,
.ui-corner-left,
.ui-corner-tl,
.ui-corner-top {
  border-top-left-radius: 0.28571rem;
}
.ui-corner-all,
.ui-corner-right,
.ui-corner-top,
.ui-corner-tr {
  border-top-right-radius: 0.28571rem;
}
.ui-corner-all,
.ui-corner-bl,
.ui-corner-bottom,
.ui-corner-left {
  border-bottom-left-radius: 0.28571rem;
}
.ui-corner-all,
.ui-corner-bottom,
.ui-corner-br,
.ui-corner-right {
  border-bottom-right-radius: 0.28571rem;
}
.ui-widget-shadow {
  margin: -0.57143rem 0 0 -0.57143rem;
  padding: 0.57143rem;
  border-radius: 0.57143rem;
}
#ui-timepicker-div,
.ui-timepicker-hours,
.ui-timepicker-minutes {
  padding: 0.2em;
}
.ps-container {
  -ms-touch-action: none;
  overflow: hidden !important;
}
.ps-container.ps-active-x > .ps-scrollbar-x-rail,
.ps-container.ps-active-y > .ps-scrollbar-y-rail {
  display: block;
}
.ps-container.ps-in-scrolling.ps-x > .ps-scrollbar-x-rail {
  background-color: #eee;
  opacity: 0.9;
}
.ps-container.ps-in-scrolling.ps-x > .ps-scrollbar-x-rail > .ps-scrollbar-x {
  background-color: #999;
}
.ps-container.ps-in-scrolling.ps-y > .ps-scrollbar-y-rail {
  background-color: #eee;
  opacity: 0.9;
}
.ps-container.ps-in-scrolling.ps-y > .ps-scrollbar-y-rail > .ps-scrollbar-y {
  background-color: #999;
}
.ps-container > .ps-scrollbar-x-rail {
  display: none;
  position: absolute;
  border-radius: 0.28571rem;
  opacity: 0;
  transition: background-color 0.2s linear, opacity 0.2s linear;
  bottom: 3px;
  bottom: 0.21429rem;
  height: 8px;
  height: 0.57143rem;
}
.ps-container > .ps-scrollbar-x-rail > .ps-scrollbar-x {
  position: absolute;
  background-color: #aaa;
  border-radius: 0.28571rem;
  transition: background-color 0.2s linear;
  bottom: 0;
  height: 8px;
  height: 0.57143rem;
}
.ps-container > .ps-scrollbar-y-rail {
  display: none;
  position: absolute;
  border-radius: 0.28571rem;
  opacity: 0;
  transition: background-color 0.2s linear, opacity 0.2s linear;
  right: 3px;
  right: 0.21429rem;
  width: 8px;
  width: 0.57143rem;
}
.ps-container > .ps-scrollbar-y-rail > .ps-scrollbar-y {
  position: absolute;
  background-color: #aaa;
  border-radius: 0.28571rem;
  transition: background-color 0.2s linear;
  right: 0;
  width: 8px;
  width: 0.57143rem;
}
.ps-container:hover.ps-in-scrolling.ps-x > .ps-scrollbar-x-rail {
  background-color: #eee;
  opacity: 0.9;
}
.ps-container:hover.ps-in-scrolling.ps-x
  > .ps-scrollbar-x-rail
  > .ps-scrollbar-x {
  background-color: #999;
}
.ps-container:hover.ps-in-scrolling.ps-y > .ps-scrollbar-y-rail {
  background-color: #eee;
  opacity: 0.9;
}
.ps-container:hover.ps-in-scrolling.ps-y
  > .ps-scrollbar-y-rail
  > .ps-scrollbar-y {
  background-color: #999;
}
.ps-container:hover > .ps-scrollbar-x-rail,
.ps-container:hover > .ps-scrollbar-y-rail {
  opacity: 0.6;
}
.ps-container:hover > .ps-scrollbar-x-rail:hover {
  background-color: #eee;
  opacity: 0.9;
}
.ps-container:hover > .ps-scrollbar-x-rail:hover > .ps-scrollbar-x {
  background-color: #999;
}
.ps-container:hover > .ps-scrollbar-y-rail:hover {
  background-color: #eee;
  opacity: 0.9;
}
.ps-container:hover > .ps-scrollbar-y-rail:hover > .ps-scrollbar-y {
  background-color: #999;
}
.ui-timepicker-inline {
  display: inline;
}
.ui-timepicker-table {
  display: inline-table;
  width: 0;
}
.ui-timepicker-table table {
  margin: 0.15em 0 0;
  border-collapse: collapse;
}
.ui-timepicker-table .ui-timepicker-title {
  line-height: 1.8em;
  text-align: center;
}
.ui-timepicker-table td,
.ui-timepicker-table th.periods {
  padding: 0.1em;
  width: 2.2em;
}
.ui-timepicker-table td a,
.ui-timepicker-table td span {
  display: block;
  padding: 0.2em 0.3em 0.2em 0.5em;
  width: 1.2em;
  text-align: right;
  text-decoration: none;
}
.ui-timepicker .ui-timepicker-buttonpane {
  background-image: none;
  margin: 0.7em 0 0;
  padding: 0 0.2em;
  border-left: 0;
  border-right: 0;
  border-bottom: 0;
}
.ui-timepicker .ui-timepicker-buttonpane button {
  margin: 0.5em 0.2em 0.4em;
  cursor: pointer;
  padding: 0.2em 0.6em 0.3em;
  width: auto;
  overflow: visible;
}
.ui-timepicker .ui-timepicker-close {
  float: right;
}
.ui-timepicker .ui-timepicker-deselect,
.ui-timepicker .ui-timepicker-now {
  float: left;
}
