/* stylelint-disable */
.inline-navigation-items .inline-navigation-item,
.inline-navigation-items .inline-navigation-item:hover {
  align-items: center;

  margin-bottom: 0;
  padding: 8px 10px;

  cursor: pointer;
}

.inline-navigation-item.section-error,
html.no-touchevents .inline-navigation-item.section-error:hover {
  background: #b13a4a;
  color: #fff;
}
.inline-navigation-item.section-error.selected {
  border-color: #b13a4a;
}
.inline-navigation-item.section-error.selected + .inline-navigation-item {
  border-top-color: #b13a4a;
}

html.no-touchevents .dragging .inline-navigation-item:hover {
  background: #f6fafc;
  color: #d0dbe6;
}

.drag-handle {
  margin-right: 10px;

  cursor: grab;
}
.dragging .inline-navigation-item,
.dragging .drag-handle {
  cursor: grabbing !important;
}

.inline-related.compact .form-row.field-order {
  display: none;
}
/* stylelint-enable */
